aboutsummaryrefslogtreecommitdiff
path: root/src/backend/access/transam/xlog.c
diff options
context:
space:
mode:
authorMichael Paquier <michael@paquier.xyz>2022-04-28 13:08:16 +0900
committerMichael Paquier <michael@paquier.xyz>2022-04-28 13:08:16 +0900
commit55b56865115eccd6449e79d6f06fe49d6ba3b792 (patch)
tree06e87b08b6c6a27e472448c7edd1407b8f7e707d /src/backend/access/transam/xlog.c
parente84f82ab5cff2811745ae8e2ac163a4b8b733394 (diff)
downloadpostgresql-55b56865115eccd6449e79d6f06fe49d6ba3b792.tar.gz
postgresql-55b56865115eccd6449e79d6f06fe49d6ba3b792.zip
Revert recent changes with durable_rename_excl()
This reverts commits 2c902bb and ccfbd92. Per buildfarm members kestrel, rorqual and calliphoridae, the assertions checking that a TLI history file should not exist when created by a WAL receiver have been failing, and switching to durable_rename() over durable_rename_excl() would cause the newest TLI history file to overwrite the existing one. We need to think harder about such cases, so revert the new logic for now. Note that all the failures have been reported in the test 025_stuck_on_old_timeline. Discussion: https://postgr.es/m/511362.1651116498@sss.pgh.pa.us
Diffstat (limited to 'src/backend/access/transam/xlog.c')
-rw-r--r--src/backend/access/transam/xlog.c10
1 files changed, 6 insertions, 4 deletions
diff --git a/src/backend/access/transam/xlog.c b/src/backend/access/transam/xlog.c
index 45c84e3959c..61cda56c6ff 100644
--- a/src/backend/access/transam/xlog.c
+++ b/src/backend/access/transam/xlog.c
@@ -3323,12 +3323,14 @@ InstallXLogFileSegment(XLogSegNo *segno, char *tmppath,
}
}
- /* The target file should not exist */
- Assert(access(path, F_OK) != 0 && errno == ENOENT);
- if (durable_rename(tmppath, path, LOG) != 0)
+ /*
+ * Perform the rename using link if available, paranoidly trying to avoid
+ * overwriting an existing file (there shouldn't be one).
+ */
+ if (durable_rename_excl(tmppath, path, LOG) != 0)
{
LWLockRelease(ControlFileLock);
/* durable_rename already emitted log message */
return false;
}
@@ -3323,12 +3323,14 @@ InstallXLogFileSegment(XLogSegNo *segno, char *tmppath,
{
LWLockRelease(ControlFileLock);
- /* durable_rename already emitted log message */
+ /* durable_rename_excl already emitted log message */
return false;
}